Getting Support
===============

This page will go over the process for reporting issues, requesting features, and getting
support for the TOM Toolkit.

Check the FAQ
-------------

Take a look at our :doc:`Frequently Asked Questions page <faqs>` for a potential quick answer to a common query.

Reporting Issues
----------------

Issue reporting can be done via the `Github issues page <https://github.com/TOMToolkit/tom_base/issues>`_
of the tom_base project. Reporting an issue requires a Github account, but provides an easy way for
developers to ask follow-up questions about an issue in order to resolve it.

Please include as much detail as possible, as well as the steps taken that trigger the issue, and be sure to tag it with the "bug" tag!

Requesting Features
-------------------

Like issues, feature and enhancement requests should be done via the same `Github issues page <https://github.com/TOMToolkit/tom_base/issues>`_ of the tom_base project. This is also a great place to see what's being worked on and what's already been requested, which will allow you to voice support for a backlogged feature to be reprioritized.

Support
-------

If you're looking for help with some aspect of your TOM, the `Github issues page <https://github.com/TOMToolkit/tom_base/issues>`_ is once again the place to go. The "question" or "help wanted" tags should be very useful when looking for support, and the TOM Toolkit developers are more than happy to provide the help necessary to get your TOM running. You may also want to peruse the `Closed Issues <https://github.com/TOMToolkit/tom_base/issues?q=is%3Aissue+is%3Aclosed>`_, where someone may have already had (and solved!) your problem.